"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
require("reflect-metadata");
const Http = require("http");
const Winston = require("winston");
const RequestMethod_1 = require("../enum/RequestMethod");
const util_1 = require("util");
class Dispatcher {
    constructor(port, handlers) {
        this.handlers = handlers;
        this.port = port;
    }
    run() {
        let server = this.getServer();
        server.listen(this.port, (error) => {
            if (error) {
                return Winston.error("Error on server start: \n" + error);
            }
            Winston.info("Dispatcher running on port " + this.port);
        });
    }
    getServer() {
        return Http.createServer((request, response) => {
            let requestMethod = request.method;
            let requestUrl = request.url;
            Winston.info("Received request [ " + requestMethod + " ]@[ " + requestUrl + " ]");
            let suitableHandler = this.handlers.find((handler) => {
                return requestUrl === handler.requestUrl &&
                    (handler.requestMethod === RequestMethod_1.RequestMethod.ANY ||
                        RequestMethod_1.RequestMethod[requestMethod] === handler.requestMethod);
            });
            if (!util_1.isNullOrUndefined(suitableHandler)) {
                Winston.info("Found suitable handler for request: [ " + requestMethod + " ]@[ " + requestUrl + " ]");
                suitableHandler.handleResponse(response);
            }
            else {
                Winston.warn("No suitable handler found for request: [ " + request.method + " ]@[ " + request.url + " ]");
            }
            response.end();
        });
    }
}
exports.Dispatcher = Dispatcher;
//# sourceMappingURL=Dispatcher.js.map