"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Pug = require("pug");
const Path = require("path");
const TemplateEngine_1 = require("../../enum/TemplateEngine");
const FileSystem = require("fs");
const NoSuchViewError_1 = require("../../error/NoSuchViewError");
class ViewResolver {
    static initialize(templatesPath, viewsPath, templateEngine) {
        this.templatesPath = templatesPath;
        this.viewsPath = viewsPath;
        this.templateEngine = templateEngine;
    }
    static getResolvedView(viewName) {
        let viewPath = Path.join(this.viewsPath, viewName);
        try {
            switch (this.templateEngine) {
                case TemplateEngine_1.TemplateEngine.NONE: {
                    return FileSystem.readFileSync(viewPath, "utf8");
                }
                case TemplateEngine_1.TemplateEngine.PUG: {
                    return Pug.renderFile(viewPath);
                }
            }
        }
        catch (error) {
            throw new NoSuchViewError_1.NoSuchViewError(viewPath);
        }
    }
}
exports.ViewResolver = ViewResolver;
//# sourceMappingURL=ViewResolver.js.map