"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Winston = require("winston");
const Key_1 = require("../../constant/Key");
const InvalidApplicationDescriptorError_1 = require("../../error/InvalidApplicationDescriptorError");
const Configuration_1 = require("../../core/model/Configuration");
const Application_1 = require("../../core/Application");
class ApplicationDescriptorProcessor {
    static process(applicationDescriptor) {
        Winston.info("               _                                    ");
        Winston.info("    /\\        | |                            _/\\_");
        Winston.info("   /  \\  _   _| |_ _   _ _ __ ___  _ __    __\\  /__");
        Winston.info("  / /\\ \\| | | | __| | | | '_ ` _ \\| '_ \\  <_      _>");
        Winston.info(" / ____ \\ |_| | |_| |_| | | | | | | | | |   |/ )\\|");
        Winston.info("/_/    \\_\\__,_|\\__|\\__,_|_| |_| |_|_| |_|     /\n");
        Winston.info("Started application descriptor analysis");
        let applicationDescriptorPrototype = Reflect.getPrototypeOf(applicationDescriptor);
        if (!Reflect.hasMetadata(Key_1.Key.METADATA_AUTUMN_APPLICATION, applicationDescriptorPrototype)) {
            throw new InvalidApplicationDescriptorError_1.InvalidApplicationDescriptorError();
        }
        let configuration;
        if (Reflect.hasMetadata(Key_1.Key.METADATA_CONFIGURATION, applicationDescriptorPrototype)) {
            configuration = Reflect.getMetadata(Key_1.Key.METADATA_CONFIGURATION, applicationDescriptorPrototype);
        }
        else {
            configuration = new Configuration_1.Configuration();
        }
        Application_1.Application.initialize(configuration);
        Winston.info("Finished application descriptor analysis");
        Application_1.Application.run();
    }
}
exports.ApplicationDescriptorProcessor = ApplicationDescriptorProcessor;
//# sourceMappingURL=ApplicationDescriptorProcessor.js.map