"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Key_1 = require("../../constant/Key");
const RequestMethod_1 = require("../../enum/RequestMethod");
const Winston = require("winston");
class ControllerProcessor {
    static process(controllers) {
        let handlers = [];
        Winston.info("Started controllers analysis");
        for (let controller of controllers) {
            controller = new controller();
            let controllerClassName = controller.constructor.name;
            Winston.info("Started [ " + controllerClassName + " ] analysis");
            let controllerPrototype = Reflect.getPrototypeOf(controller);
            if (!Reflect.hasMetadata(Key_1.Key.METADATA_CONTROLLER_BASE_PATH, controllerPrototype)) {
                Winston.warn("Skipping [ " + controllerClassName + " ] analysis: not a valid controller instance");
                continue;
            }
            let controllerHandlers = Reflect.getMetadata(Key_1.Key.METADATA_CONTROLLER_HANDLERS, controllerPrototype);
            handlers.push(...controllerHandlers);
            for (let controllerHandler of controllerHandlers) {
                Winston.info("Found handler [ " + controllerHandler.action.name + " ] " +
                    "responding to [ " + RequestMethod_1.RequestMethod[controllerHandler.requestMethod] + " ]" +
                    "@[ " + controllerHandler.requestUrl + " ]");
            }
            Winston.info("Finished analyzing [ " + controllerClassName + " ]");
        }
        Winston.info("Finished analyzing controllers");
        return handlers;
    }
}
exports.ControllerProcessor = ControllerProcessor;
//# sourceMappingURL=ControllerProcessor.js.map