import { ViewGenerator } from "./decorator/mvc/ViewGenerator";
import { RequestHandler } from "./decorator/mvc/RequestHandler";
import { Controller } from "./decorator/mvc/Controller";
import { ApplicationDescriptor } from "./decorator/configuration/ApplicationDescriptor";
import { ApplicationDescriptorProcessor } from "./decorator/processor/ApplicationDescriptorProcessor";
import { Configuration } from "./core/model/Configuration";
import { Configurator } from "./decorator/configuration/Configurator";
import { TemplateEngine } from "./enum/TemplateEngine";
import {JsonGenerator} from "./decorator/mvc/JsonGenerator";

@Controller( "/test" )
export class ExampleController {

    @RequestHandler( "/json" )
    @JsonGenerator()
    public jsonGeneratorExample(): any {
        return {
            "jsonExample": true,
            "numberExample": 1,
            "stringExample": "string"
        }
    }

    @RequestHandler( "/view" )
    @ViewGenerator()
    public viewGeneratorExample(): string {
        return "example.pug";
    }

}

@ApplicationDescriptor()
class AutumnApplicationExample {

    @Configurator()
    public configurator(): Configuration {

        return new Configuration(
            5846,
            [ ExampleController ],
            null,
            "views",
            TemplateEngine.PUG
        );

    }

}

ApplicationDescriptorProcessor.process( new AutumnApplicationExample() );