import { Handler } from "./Handler";
import "reflect-metadata";
import * as Http from "http";
import * as Winston from "winston";
import { RequestMethod } from "../enum/RequestMethod";
import { IncomingMessage, OutgoingMessage, Server } from "http";
import { isNullOrUndefined } from "util";

export class Dispatcher {

    private port: number;
    private handlers: Handler[];

    constructor( port: number, handlers: Handler[] ) {
        this.handlers = handlers;
        this.port = port;
    }

    public run(): void {

        let server: Server = this.getServer();
        server.listen( this.port, ( error ) => {

            if( error ) {
                return Winston.error( "Error on server start: \n" + error );
            }
            Winston.info( "Dispatcher running on port " + this.port );

        } );

    }

    private getServer(): Server {

        return Http.createServer( ( request: IncomingMessage, response: OutgoingMessage ) => {

            let requestMethod: string = request.method;
            let requestUrl: string = request.url;
            Winston.info( "Received request [ " + requestMethod + " ]@[ " +  requestUrl + " ]" );
            let suitableHandler: Handler = this.handlers.find( ( handler ) => {
                return requestUrl === handler.requestUrl &&
                       ( handler.requestMethod === RequestMethod.ANY ||
                         RequestMethod[ requestMethod ] === handler.requestMethod )
            } );
            if( !isNullOrUndefined( suitableHandler ) ) {
                Winston.info( "Found suitable handler for request: [ " + requestMethod + " ]@[ " +  requestUrl + " ]" );
                suitableHandler.handleResponse( response );
            }
            else {
                Winston.warn( "No suitable handler found for request: [ " + request.method + " ]@[ " +  request.url + " ]" );
            }
            response.end();

        } );

    }

}