import { RequestMethod } from "../enum/RequestMethod";
import { ResponseType } from "../enum/ResponseType";
import { ViewResolver } from "./resolver/ViewResolver";
import { OutgoingMessage } from "http";

export class Handler {

    private _requestUrl: string;
    private _requestMethod: RequestMethod;
    private _action: Function;
    private _responseType: ResponseType;

    constructor(
            requestUrl: string,
            requestMethod: RequestMethod,
            action: Function,
            responseType: ResponseType ) {
        this._requestUrl = requestUrl;
        this._requestMethod = requestMethod;
        this._action = action;
        this._responseType = responseType;

    }

    public handleResponse( response: OutgoingMessage ): void {

        let handlerResult: any = Reflect.apply( this._action, this, [] );
        switch( this._responseType ) {

            case ResponseType.JSON: {
                response.setHeader( "Content-Type", "application/json" );
                response.write( JSON.stringify( handlerResult ) );
                break;
            }
            case ResponseType.VIEW: {
                response.setHeader( "Content-Type", "text/html" );
                response.write( ViewResolver.getResolvedView( handlerResult ) );
            }

        }

    }

    public get requestUrl(): string {
        return this._requestUrl;
    }

    public set requestUrl( value: string ) {
        this._requestUrl = value;
    }

    public get requestMethod(): RequestMethod {
        return this._requestMethod;
    }

    public set requestMethod( value: RequestMethod ) {
        this._requestMethod = value;
    }

    public get action(): Function {
        return this._action;
    }

    public set action( value: Function ) {
        this._action = value;
    }

    public get responseType(): ResponseType {
        return this._responseType;
    }

    public set responseType( value: ResponseType ) {
        this._responseType = value;
    }

}