import * as Pug from "pug";
import * as Path from "path";
import { TemplateEngine } from "../../enum/TemplateEngine";
import * as FileSystem from "fs";
import * as Winston from "winston";
import { NoSuchViewError } from "../../error/NoSuchViewError";

export class ViewResolver {

    private static templatesPath: string;
    private static viewsPath: string;
    private static templateEngine: TemplateEngine;

    public static initialize( templatesPath: string, viewsPath: string, templateEngine: TemplateEngine ) {
        this.templatesPath = templatesPath;
        this.viewsPath = viewsPath;
        this.templateEngine = templateEngine;
    }

    public static getResolvedView( viewName: string ): string {

        let viewPath: string = Path.join( this.viewsPath, viewName );
        try {

            switch ( this.templateEngine ) {

                case TemplateEngine.NONE: {
                    return FileSystem.readFileSync( viewPath, "utf8" );
                }
                case TemplateEngine.PUG: {
                    return Pug.renderFile( viewPath );
                }

            }

        }
        catch( error ) {
            throw new NoSuchViewError( viewPath );
        }

    }


}