import { isNullOrUndefined } from "util";
import "reflect-metadata";
import { Key } from "../../constant/Key";
import { Handler } from "../../core/Handler";
import * as Path from "path";

export function Controller( basePath?: string ) {

    basePath = isNullOrUndefined( basePath ) ? "/" : basePath;
    return function( target: Function ) {

        let handlers: Handler[] = [];
        if( Reflect.hasMetadata( Key.METADATA_CONTROLLER_HANDLERS, target.prototype ) ) {

            handlers = Reflect.getMetadata(
                Key.METADATA_CONTROLLER_HANDLERS,
                target.prototype
            );
            for( let handler of handlers ) {
                handler.requestUrl = Path.join( basePath, handler.requestUrl );
            }

        }
        Reflect.defineMetadata(
            Key.METADATA_CONTROLLER_HANDLERS,
            handlers,
            target.prototype
        );

        Reflect.defineMetadata(
            Key.METADATA_CONTROLLER_BASE_PATH,
            basePath,
            target.prototype
        );

    }

}