import * as Winston from "winston";
import { Key } from "../../constant/Key";
import { InvalidApplicationDescriptorError } from "../../error/InvalidApplicationDescriptorError";
import { Configuration } from "../../core/model/Configuration";
import { Application } from "../../core/Application";

export class ApplicationDescriptorProcessor {

    public static process( applicationDescriptor: Object ): void {

        Winston.info( "               _                                    ");
        Winston.info( "    /\\        | |                            _/\\_" );
        Winston.info( "   /  \\  _   _| |_ _   _ _ __ ___  _ __    __\\  /__" );
        Winston.info( "  / /\\ \\| | | | __| | | | '_ ` _ \\| '_ \\  <_      _>" );
        Winston.info( " / ____ \\ |_| | |_| |_| | | | | | | | | |   |/ )\\|" );
        Winston.info( "/_/    \\_\\__,_|\\__|\\__,_|_| |_| |_|_| |_|     /\n" );

        Winston.info( "Started application descriptor analysis" );
        let applicationDescriptorPrototype: Object =
            Reflect.getPrototypeOf( applicationDescriptor );
        if( !Reflect.hasMetadata( Key.METADATA_AUTUMN_APPLICATION, applicationDescriptorPrototype ) ) {
            throw new InvalidApplicationDescriptorError();
        }

        let configuration: Configuration;
        if( Reflect.hasMetadata( Key.METADATA_CONFIGURATION, applicationDescriptorPrototype ) ) {
            configuration = Reflect.getMetadata( Key.METADATA_CONFIGURATION, applicationDescriptorPrototype );
        }
        else {
            configuration = new Configuration();
        }
        Application.initialize( configuration );
        Winston.info( "Finished application descriptor analysis" );
        Application.run();

    }

}