import { Handler } from "../../core/Handler";
import { Key } from "../../constant/Key";
import { RequestMethod } from "../../enum/RequestMethod";
import * as Winston from "winston";

export class ControllerProcessor {

    public static process( controllers: ( new() => any )[] ): Handler[] {

        let handlers: Handler[] = [];
        Winston.info( "Started controllers analysis" );
        for( let controller of controllers ) {

            controller = new controller();
            let controllerClassName = controller.constructor.name;
            Winston.info( "Started [ " + controllerClassName + " ] analysis" );

            let controllerPrototype: Object = Reflect.getPrototypeOf( controller );
            if( !Reflect.hasMetadata( Key.METADATA_CONTROLLER_BASE_PATH, controllerPrototype ) ) {
                Winston.warn( "Skipping [ " + controllerClassName + " ] analysis: not a valid controller instance" );
                continue;
            }

            let controllerHandlers: Handler[] = Reflect.getMetadata(
                Key.METADATA_CONTROLLER_HANDLERS,
                controllerPrototype
            );
            handlers.push( ...controllerHandlers );

            for( let controllerHandler of controllerHandlers ) {
                Winston.info(
                    "Found handler [ " + controllerHandler.action.name + " ] " +
                    "responding to [ " + RequestMethod[ controllerHandler.requestMethod ] + " ]" +
                    "@[ " + controllerHandler.requestUrl + " ]"
                );
            }
            Winston.info( "Finished analyzing [ " + controllerClassName + " ]" );

        }
        Winston.info( "Finished analyzing controllers" );
        return handlers;

    }



}